@@ -4,11 +4,7 @@
 #include <QObject>
 #include <QThread>
 
-#ifdef STATIC_MAUIKIT
-#include "fmh.h"
-#else
-#include <MauiKit/fmh.h>
-#endif
+#include <MauiKit/Core/fmh.h>
 
 #include "owl.h"
 
